@@ -229,12 +229,13 @@ pub fn add_changelog_entry<T: WorkingTree>(
     let mut cl =
         working_tree.edit_file::<debian_changelog::ChangeLog>(changelog_path, false, true)?;
 
-    cl.auto_add_change(
+    cl.try_auto_add_change(
         entry,
         debian_changelog::get_maintainer().unwrap(),
         None,
         None,
-    );
+    )
+    .unwrap();
 
     cl.commit()?;
 
@@ -510,10 +511,7 @@ pub fn gbp_dch(path: &std::path::Path) -> Result<(), std::io::Error> {
     cmd.current_dir(path);
     let status = cmd.status()?;
     if !status.success() {
-        return Err(std::io::Error::new(
-            std::io::ErrorKind::Other,
-            format!("gbp dch failed: {}", status),
-        ));
+        return Err(std::io::Error::other(format!("gbp dch failed: {}", status)));
     }
     Ok(())
 }
